# brief
A adaptation of the str function from R to Python


    The idea of this package is to translate useful R functions into python
    The first implementation is the R str() function to show the structure of pandas dataframes


    You can modify the lenght of the columns by changing the number of characters to display

    pystr(df, colname_len=10, dtype_len=10 ,content_len=50)
